@@ -3,12 +3,12 @@ import re
 from typing import List
 
 # Version string must appear intact for versioning
-__version__ = "7.11.0"
+__version__ = "7.13.1"
 
 # Build up version_info tuple for backwards compatibility
 pattern = r"(?P<major>\d+).(?P<minor>\d+).(?P<patch>\d+)(?P<rest>.*)"
 match = re.match(pattern, __version__)
-assert match is not None  # noqa
+assert match is not None
 parts: List[object] = [int(match[part]) for part in ["major", "minor", "patch"]]
 if match["rest"]:
     parts.append(match["rest"])
